@@ -39,6 +39,18 @@ rk5 <- function(y, times, func, parms, rtol = 1e-6, atol = 1e-6,
   rpar = NULL, ipar = NULL, nout = 0, outnames = NULL, forcings = NULL,
   initforc = NULL, fcontrol = NULL, type, stiffness = 0, ...)
 {
+  if (is.list(func)) {            # a list of compiled codes
+      if (!is.null(initfunc) & "initfunc" %in% names(func))
+         stop("If 'func' is a list that contains initfunc, argument 'initfunc' should be NULL")
+      if (!is.null(dllname) & "dllname" %in% names(func))
+         stop("If 'func' is a list that contains dllname, argument 'dllname' should be NULL")
+      if (!is.null(initforc) & "initforc" %in% names(func))
+         stop("If 'func' is a list that contains initforc, argument 'initforc' should be NULL")
+     if (!is.null(func$initfunc)) initfunc <- func$initfunc
+     if (!is.null(func$dllname))  dllname <- func$dllname     
+     if (!is.null(func$initforc)) initforc <- func$initforc
+     func <- func$func
+  }
 
 ### check input
   hmax <- checkInput (y, times, func, rtol, atol,
@@ -64,14 +76,14 @@ rk5 <- function(y, times, func, parms, rtol = 1e-6, atol = 1e-6,
   flist     <- list(fmat = 0, tmat = 0, imat = 0, ModelForc = NULL)
   ModelInit <- NULL
 
-  if (is.character(func)) {   # function specified in a DLL
+  if (is.character(func)  | class(func) == "CFunc") {   # function specified in a DLL
     DLL <- checkDLL(func,NULL,dllname,
                     initfunc,verbose,nout, outnames)
 
     ModelInit <- DLL$ModelInit
-    Func    <- DLL$Func
-    Nglobal <- DLL$Nglobal
-    Nmtot   <- DLL$Nmtot
+    Func      <- DLL$Func
+    Nglobal   <- DLL$Nglobal
+    Nmtot     <- DLL$Nmtot
 
     if (! is.null(forcings))
       flist <- checkforcings(forcings,times,dllname,initforc,verbose,fcontrol)
